@@ -1,4 +1,4 @@
 
 Lbeta <- function(x,y) {
-  .Call('Rfast_Lbeta',x,y)
+  .Call(Rfast_Lbeta,x,y)
 }
\ No newline at end of file
