@@ -1,4 +1,4 @@
 
 Lchoose <- function(x,k) {
-  .Call('Rfast_Lchoose',x,k)
+  .Call(Rfast_Lchoose,x,k)
 }
\ No newline at end of file
