@@ -1,5 +1,5 @@
 
 Outer<-function(x,y,oper="*"){
 	if(identical(oper,"%%")) oper<-"%"
-	.Call('Rfast_Outer',PACKAGE = "Rfast",x,y,oper)
+	.Call(Rfast_Outer,x,y,oper)
 }
\ No newline at end of file
