@@ -1,11 +1,10 @@
 allbetas <- function(y, x, pvalue = FALSE, logged = FALSE) {
 
-  if ( min(y) > 0 & max(y) < 1)  y <- log( y / (1 - y) )
   r <- as.vector( cov(y, x) )
   n <- length(y)
   my <- sum(y) / n
-  m <- colmeans(x)
-  sx <- colVars(x, suma = n * m)
+  m <- Rfast::colmeans(x)
+  sx <- Rfast::colVars(x, suma = n * m)
   be <- r / sx
   a <- my - be * m
 
@@ -16,7 +15,7 @@ allbetas <- function(y, x, pvalue = FALSE, logged = FALSE) {
     } else    rownames(result) <- colnames(x)
 
   } else {
-    sy <- Var(y)
+    sy <- Rfast::Var(y)
     rho2 <- r^2 / (sx * sy)
     dof <- n - 2
     stat <- r * dof / (1 - rho2)
