@@ -1,5 +1,5 @@
 
 
 apply.condition <- function(x,method = "+",oper = ">",cond.val = 0) {
-  .Call("Rfast_apply_condition",PACKAGE = "Rfast",x,method,oper,cond.val)
+  .Call(Rfast_apply_condition,x,method,oper,cond.val)
 }
\ No newline at end of file
