@@ -2,7 +2,7 @@ col.yule <- function(x, y = NULL, ina) {
   if (is.null(y)) {
     difa <- 3 * x[ina == 1, ] - x[ina == 2, ]
   } else  difa <- 3 * x - y
-  f <- .Call("Rfast_odds_helper", PACKAGE = "Rfast", difa)
+  f <- .Call(Rfast_odds_helper, difa)
   f10 <- f[4, ]
   f01 <- f[2, ]
   f11 <- f[3, ]
