@@ -7,15 +7,15 @@ gammanb <- function(xnew = NULL, x, ina, tol = 1e-07) {
   a <- matrix(0, k, d)
   b <- matrix(0, k, d)
   for (i in 1:k)  {
-    res <- colgammamle( x[ina==i, ] )[, 1:2]
+    res <- Rfast::colgammamle( x[ina==i, ] )[, 1:2]
     a[i, ] <- res[, 1]
     b[i, ] <- res[, 2]
   }
   rownames(a) <- rownames(b) <- paste("Group", 1:k)
   if ( is.null(xnew) ) {
-    score <-   - tcrossprod(b, xnew) + tcrossprod(a - 1, Log(xnew)) - 
-    rowsums( Lgamma(a) - a * Log(b) )
-	est <- colMaxs(score)
+    score <-  - tcrossprod(b, xnew) + tcrossprod(a - 1, Rfast::Log(xnew)) - 
+    Rfast::rowsums( Rfast::Lgamma(a) - a * Rfast::Log(b) )
+	est <- Rfast::colMaxs(score)
   }
   list( a = a, b = b, est = est )
 }  
\ No newline at end of file
