@@ -1,6 +1,6 @@
 glm_logistic <- function (x, y, full = FALSE, tol = 1e-09,maxiters = 100) {
     x <- model.matrix(y ~ ., data.frame(x))
-    mod <- .Call("Rfast_glm_logistic",PACKAGE = "Rfast", x, y,tol,maxiters)
+    mod <- .Call(Rfast_glm_logistic, x, y,tol,maxiters)
     res <- list(be = mod$be, devi = mod$deviance)
     if (full) {
         be <- mod$be
