@@ -1,15 +1,15 @@
 hd.eigen <- function(x, center = TRUE, scale = FALSE, k = NULL, vectors = FALSE) {
     n <- dim(x)[1]
     if (center & scale) {
-        y <- t(x) - colmeans(x)
-        y <- y/sqrt(rowsums(y^2)) * sqrt(n - 1)
+        y <- t(x) - Rfast::colmeans(x)
+        y <- y/sqrt(Rfast::rowsums(y^2)) * sqrt(n - 1)
         xx <- crossprod(y)
     }   else if (center & !scale) {
-        m <- colmeans(x) 
+        m <- Rfast::colmeans(x) 
         y <- t(x) - m
         xx <- crossprod(y)
     }   else if (!center & scale) {
-        s <- colVars(x, std = TRUE)
+        s <- Rfast::colVars(x, std = TRUE)
         y <- t(x) / s 
         xx <- crossprod(y)
     }   else {
@@ -21,7 +21,7 @@ hd.eigen <- function(x, center = TRUE, scale = FALSE, k = NULL, vectors = FALSE)
     L <- a$values[1:k]
 	
     if (vectors) {
-	FF <- submatrix(a$vectors, 1, n, 1, k)
+	FF <- Rfast::submatrix(a$vectors, 1, n, 1, k)
       vectors <- tcrossprod(y, t(FF) * L^(-0.5) )
     } else  vectors <- NULL
     list(values = L/(n - 1), vectors = vectors)
