@@ -1,4 +1,4 @@
 
 mad2 <- function(x,method = "median",na.rm = FALSE) {
-	.Call('Rfast_mad2', PACKAGE = 'Rfast',x,method,na.rm)
+	.Call(Rfast_mad2,x,method,na.rm)
 }
\ No newline at end of file
