@@ -4,5 +4,5 @@ multinom.nb <- function(xnew, x, ina) {
   x <- x / Rfast::rowsums(x)  ## normalizes the data, so that each observation sums to 1
   m <- rowsum(x, ina) / ni
   score <- tcrossprod( xnew, log(m) )
-  rowMaxs(score)
+  Rfast::rowMaxs(score)
 }
\ No newline at end of file
