@@ -1,4 +1,4 @@
 multinomnb.pred <- function(xnew, m) {
   score <- tcrossprod( xnew, log(m) )
-  rowMaxs(score)
+  Rfast::rowMaxs(score)
 }
\ No newline at end of file
