@@ -7,8 +7,7 @@ normlog.regs <- function (y, x, tol = 1e-08, logged = FALSE, parallel = FALSE,
    con <- Rfast::Var(y) * (n - 1)
    be <- allbetas( ly, x )
 
-   mod <- .Call("Rfast_normlog_regs", PACKAGE = "Rfast", y, 
-        x, be, con, tol, logged, parallel, maxiters)
+   mod <- .Call(Rfast_normlog_regs, y, x, be, con, tol, logged, parallel, maxiters)
 
     colnames(mod) <- c("stat", "pvalue")
     mod
