@@ -1,4 +1,4 @@
 
 permutation.next <- function(x,nperm=gamma(length(x)+1)) {
-  .Call('Rfast_permutation_next', PACKAGE = 'Rfast',x,nperm)
+  .Call(Rfast_permutation_next,x,nperm)
 }
\ No newline at end of file
