@@ -1,4 +1,4 @@
 
 permutation.prev <- function(x,nperm=gamma(length(x)+1)) {
-  .Call('Rfast_permutation_prev', PACKAGE = 'Rfast',x,nperm)
+  .Call(Rfast_permutation_prev,x,nperm)
 }
\ No newline at end of file
