@@ -1,5 +1,5 @@
 
 
 rowTabulate <- function(x, max_number = max(x)) {
-  .Call('Rfast_row_tabulate',x,max_number)
+  .Call(Rfast_row_tabulate,x,max_number)
 }
\ No newline at end of file
