@@ -6,5 +6,5 @@ total.dist <- function(x,method = "euclidean", square = FALSE,p=0) {
   if(method == "hellinger"){
     x <- sqrt(x)
   }
-  .Call("Rfast_total_dists",PACKAGE = "Rfast",x,method,square,p)
+  .Call(Rfast_total_dists,x,method,square,p)
 }
\ No newline at end of file
