@@ -12,10 +12,10 @@ ttests <- function(x, y = NULL, ina, paired = FALSE, logged = FALSE, parallel =
 	  x2 <- y     ;    n2 <- dim(x2)[1]
     }
 
-    m1 <- colmeans(x1, parallel = parallel)
-    m2 <- colmeans(x2, parallel = parallel)
-    f1 <- colVars(x1, suma = n1 * m1, parallel = parallel) / n1
-    f2 <- colVars(x2, suma = n2 * m2, parallel = parallel) / n2
+    m1 <- Rfast::colmeans(x1, parallel = parallel)
+    m2 <- Rfast::colmeans(x2, parallel = parallel)
+    f1 <- Rfast::colVars(x1, suma = n1 * m1, parallel = parallel) / n1
+    f2 <- Rfast::colVars(x2, suma = n2 * m2, parallel = parallel) / n2
     fac <- f1 + f2
     dof <- fac^2 / ( f1^2 / (n1 - 1) + f2^2 / (n2 - 1) )
     stat <- ( m1 - m2 ) / sqrt(fac)
@@ -29,8 +29,8 @@ ttests <- function(x, y = NULL, ina, paired = FALSE, logged = FALSE, parallel =
     if ( is.null(y) ) {
       z <- x[ ina == 1, ] - x[ ina == 2, ]
     } else  z <- x - y    
-    m <- colmeans(z, parallel = parallel)
-    s <- colVars(z, suma = n * m, std = TRUE, parallel = parallel)
+    m <- Rfast::colmeans(z, parallel = parallel)
+    s <- Rfast::colVars(z, suma = n * m, std = TRUE, parallel = parallel)
     stat <- sqrt(n) * m / s
     if ( logged ) {
       pvalue <- log(2) + pt( abs(stat), n - 1, lower.tail = FALSE, log.p = TRUE )  
