@@ -1,35 +1,38 @@
 //Author: Manos Papadakis
 
 #include <RcppArmadillo.h>
-#include "mn.h"
+#include "templates.h"
 
 using namespace Rcpp;
 using namespace arma;
 
-//[[Rcpp::export]]
 double Norm(NumericMatrix x, const char type) {
+	double s=0.0;
 	if(type=='F')
-		return sumsqr(x);
-	mat xx(x.begin(),x.nrow(),x.ncol(),false);
-	switch(type){
-		case 'C':{
-			rowvec a=sum(abs(xx),0);
-			return a[a.index_max()];
-		}
-		case 'R':{
-			mat xx(x.begin(),x.nrow(),x.ncol(),false);
-			colvec a=sum(abs(xx),1);
-			return a[a.index_max()];
-		}
-		case 'M':{
-			return xx[xx.index_max()];
-			
-		}
-		default:{
-			stop("Wrong type. You have to give one of <F,C,R,M>.\n");
+		s=sum_with< square2<double>,NumericMatrix>(x);
+	else{
+		mat xx(x.begin(),x.nrow(),x.ncol(),false);
+		switch(type){
+			case 'C':{
+				rowvec a=sum(abs(xx),0);
+				s=a[a.index_max()];
+				break;
+			}
+			case 'R':{
+				colvec a=sum(abs(xx),1);
+				s=a[a.index_max()];
+				break;
+			}
+			case 'M':{
+				s=xx[xx.index_max()];
+				break;
+			}
+			default:{
+				stop("Wrong type. You have to give one of <F,C,R,M>.\n");
+			}
 		}
 	}
-	return 0.0;
+	return s;
 }
 
 
