@@ -16,10 +16,19 @@ NumericMatrix dir_knn(NumericMatrix tXnew, NumericMatrix tX, NumericVector Y, Nu
 
   double (*_function_type_)(vec, a_node*, const int);
 
-  if(type=="C")
-    _function_type_ = &most_frequent_value;
-  else
+  if(type == "R"){
     _function_type_ = &average_value;
+  }
+  else if(type == "WR"){
+    _function_type_ = &weighted_average_value;
+  }
+  else if(type == "WC"){
+    _function_type_ = &weighted_most_frequent_value;
+  }
+  else{
+   _function_type_ = &most_frequent_value;
+  }
+
 
   int d = tX.nrow(), n = tX.ncol(), nu = tXnew.ncol(), klen = K.size();
   mat txnew(tXnew.begin(), d, nu,false), tx(tX.begin(), d,n,false);
@@ -27,20 +36,48 @@ NumericMatrix dir_knn(NumericMatrix tXnew, NumericMatrix tX, NumericVector Y, Nu
   int k0 = max(K);
 
   if(k0>n)
-    k0=n;
+    k0=n-1;
 
   NumericMatrix g = NumericMatrix(nu,klen);
 
-  #ifdef _OPENMP
-  #pragma omp parallel if(parallel)
-  {
-  #endif
+  if(parallel){
+      #ifdef _OPENMP
+      #pragma omp parallel
+      {
+      #endif
+        // create a sorted array of size k0
+        a_node* myarray = init_array(k0);
+        double tmpsum;
+        #ifdef _OPENMP
+        #pragma omp for
+        #endif
+        for (int l = 0; l < nu; l++) {
+          for(int i = 0; i < n; i++){
+            tmpsum = sum(tx.col(i)%txnew.col(l));
+            if(tmpsum > 1)
+              tmpsum = 1;
+            else if(tmpsum < -1)
+              tmpsum = -1;
+            k_sorted_put(myarray,k0,i,acos(tmpsum));
+          }
+
+          for(int j = 0; j < klen; j++){
+            g(l,j)= _function_type_(y, myarray, K[j]);
+          }
+
+            // make all elements of the array "invalid" so that the next iteration can begin
+            myarray =  refresh_array(myarray, k0);
+        }
+        clear_array(myarray);
+      #ifdef _OPENMP
+      }
+      #endif
+  }
+  else{
     // create a sorted array of size k0
     a_node* myarray = init_array(k0);
     double tmpsum;
-    #ifdef _OPENMP
-    #pragma omp for
-    #endif
+
     for (int l = 0; l < nu; l++) {
       for(int i = 0; i < n; i++){
         tmpsum = sum(tx.col(i)%txnew.col(l));
@@ -51,21 +88,19 @@ NumericMatrix dir_knn(NumericMatrix tXnew, NumericMatrix tX, NumericVector Y, Nu
         k_sorted_put(myarray,k0,i,acos(tmpsum));
       }
 
-      for(int j = 0; j < klen; j++)
+      for(int j = 0; j < klen; j++){
         g(l,j)= _function_type_(y, myarray, K[j]);
+      }
 
         // make all elements of the array "invalid" so that the next iteration can begin
         myarray =  refresh_array(myarray, k0);
     }
     clear_array(myarray);
-  #ifdef _OPENMP
   }
-  #endif
 
   return g;
 }
 
-
 RcppExport SEXP Rfast_dir_knn(SEXP tXnewSEXP,SEXP tXSEXP,SEXP YSEXP,SEXP KSEXP,SEXP typeSEXP,SEXP parallelSEXP) {
 BEGIN_RCPP
     RObject __result;
